STM32F103C8T6_WIFI_Heating_system

Dependencies:   mbed mbed-STM32F103C8T6 eeprom_flash Watchdog PinDetect DS1820

  1. Bluepill STM32F103C8T6 Heating system
    1. _This project is core part of bigger heating system project!_

Features - Reading temperature from four DS18B20 sensors - Making a decision about switching on/off heater and pomp - Executing simple user commands from UART - Storing state parameters to program memory (EEPROM emulation)

Revision:
18:9434e06223c7
Parent:
17:718e41e971f8
Child:
19:74f78a777ffa
--- a/main.cpp	Wed Sep 12 16:51:13 2018 +0000
+++ b/main.cpp	Wed Sep 12 17:40:02 2018 +0000
@@ -35,7 +35,9 @@
     confSysClock();     //Configure system clock (72MHz HSE clock, 48MHz USB clock)
     DigitalOut  myled(LED1);
     
-    DS1820  ds1820(PA_9);    // substitute PA_9 with actual mbed pin name connected to the DS1820 data pin                             
+    DS1820  ds1820(PA_9);    // substitute PA_9 with actual mbed pin name connected to the DS1820 data pin           
+    DS1820  ds1820_2(PA_8);    // substitute PA_9 with actual mbed pin name connected to the DS1820 data pin           
+                      
     float   temp = 0;
     int     error = 0; 
     
@@ -44,11 +46,19 @@
     pc.printf("Hello world! Mbed version\r\n");
     
     if(ds1820.begin()) {
-        pc.printf("DS1820 sensor found!\r\n");    
+        pc.printf("DS1820 sensor1 found!\r\n");    
     } else {
-        pc.printf("No DS1820 sensor found!\r\n");
+        pc.printf("No DS1820 sensor1 found!\r\n");
     };
     
+    
+    if(ds1820_2.begin()) {
+        pc.printf("DS1820 sensor2 found!\r\n");    
+    } else {
+        pc.printf("No DS1820 sensor2 found!\r\n");
+    };
+    
+    
     while(1) {
         // The on-board LED is connected, via a resistor, to +3.3V (not to GND). 
         // So to turn the LED on or off we have to set it to 0 or 1 respectively
@@ -67,19 +77,33 @@
         
         
         ds1820.startConversion();  // start temperature conversion from analog to digital
-            wait(1.0);                 // let DS1820 complete the temperature conversion 
+        ds1820_2.startConversion();  // start temperature conversion from analog to digital
+        
+            wait(0.750);                 // let DS1820 complete the temperature conversion 
             error = ds1820.read(temp); // read temperature from DS1820 and perform cyclic redundancy check (CRC)
             switch(error) {
             case 0:    // no errors -> 'temp' contains the value of measured temperature
-                pc.printf("sensor temp = %3.1f%cC\r\n", temp, 176);
+                pc.printf("sensor1 temp = %3.1fC\r\n", temp, 176);
                 break;
             case 1:    // no sensor present -> 'temp' is not updated
-                pc.printf("no sensor present\n\r");
+                pc.printf("no sensor1 present\n\r");
                 break;
             case 2:    // CRC error -> 'temp' is not updated
-                pc.printf("sensor CRC error\r\n");
+                pc.printf("sensor1 CRC error\r\n");
+            }; 
+            
+            error = ds1820_2.read(temp); // read temperature from DS1820 and perform cyclic redundancy check (CRC)
+            switch(error) {
+            case 0:    // no errors -> 'temp' contains the value of measured temperature
+                pc.printf("sensor2 temp = %3.1fC\r\n", temp, 176);
+                break;
+            case 1:    // no sensor present -> 'temp' is not updated
+                pc.printf("no sensor2 present\n\r");
+                break;
+            case 2:    // CRC error -> 'temp' is not updated
+                pc.printf("sensor2 CRC error\r\n");
             } 
-        
+